@@ -2,13 +2,12 @@ from .exceptions import NextLogicBlock
 from .serializers import EmptySerializer, MockSerializer
 from .views import BasePipelineView
 
-
 try:
-    import uvloop  # noqa pylint: disable=import-error
+    import uvloop  # noqa
 
     uvloop.install()  # pragma: no cover
-except Exception:  # noqa pylint: disable=broad-except
-    pass
+except Exception:  # noqa
+    pass  # noqa
 
 
 __all__ = [
